@@ -1,9 +1,6 @@
 from .contentgrid import *
-from ._panel import *
-from ._datamanager import *
 from ._dynamicpanel import *
 from .basetab import *
-from .controlplugin import *
 from .datapanel import *
 from .plotpanel import *
 from .quickboard import *
